summaryrefslogtreecommitdiff
path: root/fs/xfs/xfs_iops.c
diff options
context:
space:
mode:
authorJan Kara <jack@suse.cz>2016-12-14 13:24:48 +0100
committerSasha Levin <alexander.levin@verizon.com>2016-12-23 08:56:35 -0500
commitcb8e1eef351b640cfdb1a753ef44494fbf59186d (patch)
tree0082747a79745f6c1b525077d21f796de21692d0 /fs/xfs/xfs_iops.c
parent2ee3ceeccd34c3fe589506c0fd822a8773a828bf (diff)
fs: Give dentry to inode_change_ok() instead of inode
[ Upstream commit 31051c85b5e2aaaf6315f74c72a732673632a905 ] inode_change_ok() will be resposible for clearing capabilities and IMA extended attributes and as such will need dentry. Give it as an argument to inode_change_ok() instead of an inode. Also rename inode_change_ok() to setattr_prepare() to better relect that it does also some modifications in addition to checks. References: CVE-2015-1350 Reviewed-by: Christoph Hellwig <hch@lst.de> Signed-off-by: Jan Kara <jack@suse.cz> Signed-off-by: Philipp Hahn <hahn@univention.de> Signed-off-by: Sasha Levin <alexander.levin@verizon.com>
Diffstat (limited to 'fs/xfs/xfs_iops.c')
-rw-r--r--fs/xfs/xfs_iops.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/fs/xfs/xfs_iops.c b/fs/xfs/xfs_iops.c
index 274b8b99edfa..4e4d6511185b 100644
--- a/fs/xfs/xfs_iops.c
+++ b/fs/xfs/xfs_iops.c
@@ -552,14 +552,14 @@ xfs_vn_change_ok(
if (XFS_FORCED_SHUTDOWN(mp))
return -EIO;
- return inode_change_ok(inode, iattr);
+ return setattr_prepare(dentry, iattr);
}
/*
* Set non-size attributes of an inode.
*
* Caution: The caller of this function is responsible for calling
* inode_change_ok() or otherwise verifying the change is fine.
*/
int
xfs_setattr_nonsize(
@@ -770,7 +770,7 @@ xfs_vn_setattr_nonsize(
* Truncate file. Must have write permission and not be a directory.
*
* Caution: The caller of this function is responsible for calling
* inode_change_ok() or otherwise verifying the change is fine.
*/
int
xfs_setattr_size(
@@ -552,14 +552,14 @@ xfs_vn_change_ok(
*
* Caution: The caller of this function is responsible for calling
- * inode_change_ok() or otherwise verifying the change is fine.
+ * setattr_prepare() or otherwise verifying the change is fine.
*/
int
@@ -770,7 +770,7 @@ xfs_vn_setattr_nonsize(
*
* Caution: The caller of this function is responsible for calling
- * inode_change_ok() or otherwise verifying the change is fine.
+ * setattr_prepare() or otherwise verifying the change is fine.
*/
int